Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1953)

Unified Diff: components/feature_engagement_tracker/internal/condition_validator.h

Issue 2911123003: Metrics for feature engagement tracker. (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/feature_engagement_tracker/internal/condition_validator.h
diff --git a/components/feature_engagement_tracker/internal/condition_validator.h b/components/feature_engagement_tracker/internal/condition_validator.h
index 2f8f7a59bc205f5c9f3ffb0f75de387c40851555..a4686e036167ee8a4db23ec844861a55800d54ac 100644
--- a/components/feature_engagement_tracker/internal/condition_validator.h
+++ b/components/feature_engagement_tracker/internal/condition_validator.h
@@ -33,8 +33,8 @@ class ConditionValidator {
explicit Result(bool initial_values);
Result(const Result& other);
- // Whether the Model was ready.
- bool model_ready_ok;
+ // Whether the event model was ready.
+ bool event_model_ready_ok;
// Whether no other in-product helps were shown at the time.
bool currently_showing_ok;
@@ -65,7 +65,7 @@ class ConditionValidator {
// Returns true if this result object has no errors, i.e. no values that
// are false.
- bool NoErrors();
+ bool NoErrors() const;
};
virtual ~ConditionValidator() = default;

Powered by Google App Engine
This is Rietveld 408576698